@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber::Model::Feature;
-$Test::BDD::Cucumber::Model::Feature::VERSION = '0.26';
+$Test::BDD::Cucumber::Model::Feature::VERSION = '0.27';
 use Moose;
 
 =head1 NAME
@@ -8,7 +8,7 @@ Test::BDD::Cucumber::Model::Document - Model to represent a feature file, parsed
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 DESCRIPTION
 
@@ -22,7 +22,7 @@ The text after the C<Feature:> keyword
 
 =cut
 
-has 'name'         => ( is => 'rw', isa => 'Str' );
+has 'name' => ( is => 'rw', isa => 'Str' );
 
 =head2 name_line
 
@@ -31,7 +31,7 @@ C<Feature> keyword was found on
 
 =cut
 
-has 'name_line'    => ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Line' );
+has 'name_line' => ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Line' );
 
 =head2 satisfaction
 
@@ -39,8 +39,11 @@ An arrayref of strings of the Conditions of Satisfaction
 
 =cut
 
-has 'satisfaction' => ( is => 'rw', isa => 'ArrayRef[Test::BDD::Cucumber::Model::Line]',
-	default => sub {[]});
+has 'satisfaction' => (
+    is      => 'rw',
+    isa     => 'ArrayRef[Test::BDD::Cucumber::Model::Line]',
+    default => sub { [] }
+);
 
 =head2 document
 
@@ -48,7 +51,7 @@ The corresponding L<Test::BDD::Cucumber::Model::Document> object
 
 =cut
 
-has 'document'   => ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Document' );
+has 'document' => ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Document' );
 
 =head2 background
 
@@ -57,7 +60,8 @@ background section.
 
 =cut
 
-has 'background' => ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Scenario' );
+has 'background' =>
+  ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Scenario' );
 
 =head2 scenarios
 
@@ -66,8 +70,11 @@ constitute the test.
 
 =cut
 
-has 'scenarios' => ( is => 'rw', isa => 'ArrayRef[Test::BDD::Cucumber::Model::Scenario]',
-	default => sub {[]} );
+has 'scenarios' => (
+    is      => 'rw',
+    isa     => 'ArrayRef[Test::BDD::Cucumber::Model::Scenario]',
+    default => sub { [] }
+);
 
 =head2 tags
 
@@ -76,7 +83,7 @@ Scenarios.
 
 =cut
 
-has 'tags' => ( is => 'rw', isa => 'ArrayRef[Str]', default => sub {[]} );
+has 'tags' => ( is => 'rw', isa => 'ArrayRef[Str]', default => sub { [] } );
 
 =head2 language
 
@@ -84,8 +91,11 @@ Language the feature is written in. Defaults to 'en'.
 
 =cut
 
-has 'language' => ( is => 'rw', isa => 'Str',
-	default => sub { 'en' });
+has 'language' => (
+    is      => 'rw',
+    isa     => 'Str',
+    default => sub { 'en' }
+);
 
 =head1 AUTHOR
 
