@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber::Model::Scenario;
-$Test::BDD::Cucumber::Model::Scenario::VERSION = '0.25';
+$Test::BDD::Cucumber::Model::Scenario::VERSION = '0.27';
 use Moose;
 
 =head1 NAME
@@ -8,7 +8,7 @@ Test::BDD::Cucumber::Model::Scenario - Model to represent a scenario
 
 =head1 VERSION
 
-version 0.25
+version 0.27
 
 =head1 DESCRIPTION
 
@@ -22,7 +22,7 @@ The text after the C<Scenario:> keyword
 
 =cut
 
-has 'name'       => ( is => 'rw', isa => 'Str' );
+has 'name' => ( is => 'rw', isa => 'Str' );
 
 =head2 steps
 
@@ -30,7 +30,11 @@ The associated L<Test:BDD::Cucumber::Model::Step> objects
 
 =cut
 
-has 'steps'      => ( is => 'rw', isa => 'ArrayRef[Test::BDD::Cucumber::Model::Step]', default => sub {[]} );
+has 'steps' => (
+    is      => 'rw',
+    isa     => 'ArrayRef[Test::BDD::Cucumber::Model::Step]',
+    default => sub { [] }
+);
 
 =head2 data
 
@@ -38,7 +42,7 @@ Scenario-related data table, as an arrayref of hashrefs
 
 =cut
 
-has 'data'       => ( is => 'rw', isa => 'ArrayRef[HashRef]', default => sub {[]} );
+has 'data' => ( is => 'rw', isa => 'ArrayRef[HashRef]', default => sub { [] } );
 
 =head2 background
 
@@ -55,7 +59,7 @@ the C<Scenario> keyword is.
 
 =cut
 
-has 'line'       => ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Line' );
+has 'line' => ( is => 'rw', isa => 'Test::BDD::Cucumber::Model::Line' );
 
 =head2 tags
 
@@ -64,7 +68,7 @@ feature.
 
 =cut
 
-has 'tags' => ( is => 'rw', isa => 'ArrayRef[Str]', default => sub {[]} );
+has 'tags' => ( is => 'rw', isa => 'ArrayRef[Str]', default => sub { [] } );
 
 =head1 AUTHOR
 
